@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Manipulate the position of a note in a scale
 
-our $VERSION = '0.0505';
+our $VERSION = '0.0506';
 
 use Carp;
 use List::Util qw( first );
@@ -92,7 +92,7 @@ sub get_offset {
         $offset += $posn;
     }
     else {
-        warn "Scale position not defined!\n";
+        croak 'Scale position not defined!';
     }
 
     my $octave = $note->octave;
@@ -107,8 +107,8 @@ sub get_offset {
 
     $note = Music::Note->new( $scale[ $offset % @scale ] . $octave, 'ISO' );
 
-    warn sprintf "\tNew offset: %d, ISO: %s, Formatted: %s\n",
-        $offset, $note->format('ISO'), $note->format($format)
+    warn sprintf "\tNew offset: %d, octave: %d, ISO: %s, Formatted: %s\n",
+        $offset, $octave, $note->format('ISO'), $note->format($format)
         if $self->verbose;
 
     return $note;
@@ -128,7 +128,7 @@ Music::ScaleNote - Manipulate the position of a note in a scale
 
 =head1 VERSION
 
-version 0.0505
+version 0.0506
 
 =head1 SYNOPSIS
 
@@ -146,8 +146,8 @@ version 0.0505
   print $note->format('ISO'), "\n"; # D#4
 
   $msn = Music::ScaleNote->new(
-    scale_note  => 'C',
-    scale_name  => 'major',
+    scale_note => 'C',
+    scale_name => 'major',
   );
 
   $note = $msn->get_offset(
@@ -167,10 +167,10 @@ B<note_format>, and a scale position B<offset>, the new note is
 computed.
 
 So for scale C<C D# F G A#> (C pentatonic minor), note name C<C4>
-(given the ISO format), and offset C<1> (move one scale step to the
-right), the note C<D#4> is returned.
+(in ISO format), and offset C<1> (move one scale step to the right),
+the note C<D#4> is returned.
 
-For offset of C<-1>, the note C<A#3> is returned.
+For an offset of C<-1>, the note C<A#3> is returned.
 
 =head1 ATTRIBUTES
 
@@ -258,10 +258,10 @@ format and note name is B<not> how to use this module.
 
 The F<t/01-methods.t> file in this distribution.
 
-L<Moo>
-
 L<List::Util>
 
+L<Moo>
+
 L<Music::Note>
 
 L<Music::Scales>
